You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by aj...@apache.org on 2005/09/12 09:08:38 UTC

svn commit: r280276 - in /webservices/axis2/trunk/java/modules/core: src/org/apache/axis2/clientapi/ src/org/apache/axis2/context/ src/org/apache/axis2/description/ test/org/apache/axis2/engine/

Author: ajith
Date: Mon Sep 12 00:08:14 2005
New Revision: 280276

URL: http://svn.apache.org/viewcvs?rev=280276&view=rev
Log:
Refactored the method name createMEPContext to createoperationContxt
Refactored the serviceInstanceId ro serviceContextId

Modified:
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOutMEPClient.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/MessageContext.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContextFactory.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EngineWithoutPhaseResolvingTest.java

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOutMEPClient.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOutMEPClient.java?rev=280276&r1=280275&r2=280276&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOutMEPClient.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/clientapi/InOutMEPClient.java Mon Sep 12 00:08:14 2005
@@ -175,7 +175,7 @@
             //find and set the Operation Context
             ConfigurationContext sysContext = serviceContext.getEngineContext();
             AxisConfiguration registry = sysContext.getAxisConfiguration();
-            msgctx.setOperationContext(OperationContextFactory.createMEPContext(WSDLConstants.MEP_CONSTANT_IN_OUT,
+            msgctx.setOperationContext(OperationContextFactory.createOperationContext(WSDLConstants.MEP_CONSTANT_IN_OUT,
                     axisop,
                     serviceContext));
             //Send the SOAP Message and receive a response                
@@ -404,7 +404,7 @@
 
         public void doWork() {
             try {
-                msgctx.setOperationContext(OperationContextFactory.createMEPContext(WSDLConstants.MEP_CONSTANT_IN_OUT,
+                msgctx.setOperationContext(OperationContextFactory.createOperationContext(WSDLConstants.MEP_CONSTANT_IN_OUT,
                         axisop,
                         serviceContext));
                 msgctx.setServiceContext(serviceContext);

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/MessageContext.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/MessageContext.java?rev=280276&r1=280275&r2=280276&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContextFactory.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContextFactory.java Mon Sep 12 00:08:14 2005
@@ -28,7 +28,7 @@
 
 public class OperationContextFactory implements WSDLConstants {
 
-    public static OperationContext createMEPContext(
+    public static OperationContext createOperationContext(
         int mepURI,
         OperationDescription axisOp,
         ServiceContext serviceContext)

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java?rev=280276&r1=280275&r2=280276&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/OperationDescription.java Mon Sep 12 00:08:14 2005
@@ -194,7 +194,7 @@
             //Its a new incomming message so get the factory to create a new
             // one
             operationContext =
-                    OperationContextFactory.createMEPContext(
+                    OperationContextFactory.createOperationContext(
                             getAxisSpecifMEPConstant(), this,
                             serviceContext);
 

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java?rev=280276&r1=280275&r2=280276&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ServiceDescription.java Mon Sep 12 00:08:14 2005
@@ -580,16 +580,16 @@
      */
     public ServiceContext findServiceContext(MessageContext msgContext) {
         ServiceContext serviceContext = null;
-        if (null == msgContext.getServiceInstanceID()) {
+        if (null == msgContext.getServiceContextID()) {
             serviceContext =
                     new ServiceContext(this, msgContext.getSystemContext());
             //TODO Once the ServiceContext is bound to an incomming serviceContext ID(like a cookie,reference Property) FIX this
-            //			msgContext.getSystemContext().registerServiceContext(serviceContext.getServiceInstanceID(),
+            //			msgContext.getSystemContext().registerServiceContext(serviceContext.getServiceContextID(),
             // serviceContext);
         } else {
             serviceContext =
                     msgContext.getSystemContext()
-                            .getServiceContext(msgContext.getServiceInstanceID());
+                            .getServiceContext(msgContext.getServiceContextID());
         }
 
         return serviceContext;

Modified: webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EngineWithoutPhaseResolvingTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EngineWithoutPhaseResolvingTest.java?rev=280276&r1=280275&r2=280276&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EngineWithoutPhaseResolvingTest.java (original)
+++ webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/engine/EngineWithoutPhaseResolvingTest.java Mon Sep 12 00:08:14 2005
@@ -85,7 +85,7 @@
                         transport);
 
         mc.setOperationContext(
-                OperationContextFactory.createMEPContext(
+                OperationContextFactory.createOperationContext(
                         WSDLConstants.MEP_CONSTANT_IN_OUT,
                         axisOp,
                         serviceContext));
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/MessageContext.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/MessageContext.java Mon Sep 12 00:08:14 2005
@@ -141,7 +141,7 @@
 
     public boolean outPutWritten = false;
 
-    private String serviceInstanceID;
+    private String serviceContextID;
 
     private String pausedPhaseName;
 
@@ -496,17 +496,17 @@
     }
 
     /**
-     * @return Returns the serviceInstanceID.
+     * @return Returns the serviceContextID.
      */
-    public String getServiceInstanceID() {
-        return serviceInstanceID;
+    public String getServiceContextID() {
+        return serviceContextID;
     }
 
     /**
      * @param serviceInstanceID The serviceInstanceID to set.
      */
-    public void setServiceInstanceID(String serviceInstanceID) {
-        this.serviceInstanceID = serviceInstanceID;
+    public void setServiceContextID(String serviceContextID) {
+        this.serviceContextID = serviceContextID;
     }
 
     public ConfigurationContext getSystemContext() {
@@ -496,17 +496,17 @@
 
     /**
-     * @param serviceInstanceID The serviceInstanceID to set.
+     * @param serviceContextID The serviceContextID to set.
      */

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContextFactory.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/context/OperationContextFactory.java?rev=280276&r1=280275&r2=280276&view=diff
==============================================================================